import React from 'react';
import { compose, withProps } from "recompose";
import { withScriptjs, withGoogleMap, StreetViewPanorama, GoogleMap, Marker } from "react-google-maps";
import RoundTimer from "./round-timer.component";

// TODO want a button for moving the pano back to start somehow

const getMapUrl = googleApiKey => `https://maps.googleapis.com/maps/api/js?key=${googleApiKey}&v=3.exp&libraries=geometry,drawing,places`

const PositionedStreetView = compose(
  withProps({
    loadingElement: <div style={{ height: `100%` }} />,
    containerElement: <div style={{ height: "100%" }} />,
    mapElement: <div style={{ height: `100%` }} />,
  }),
  withScriptjs,
  withGoogleMap
)(({ point }) =>
  <StreetViewPanorama
    defaultPosition={point}
    options={{
      addressControl: false,
      showRoadLabels: false,
      clickToGo: true,
    }}
    visible
  />
);

const SelectionMap = compose(
  withProps({
    loadingElement: <div style={{ height: `100%` }} />,
    containerElement: <div style={{ height: `100%` }} />,
    mapElement: <div style={{ height: `100%` }} />,
  }),
  withScriptjs,
  withGoogleMap
)(({onClick, markerPosition}) =>
  <GoogleMap
    defaultZoom={1}
    defaultCenter={{ lat: 25, lng: -25}}
    clickableIcons={false}
    options={{
      disableDefaultUI: true,
      fullscreenControl: true,
    }}
    onClick={onClick}>
      {markerPosition ? <Marker
        clickable={false}
        draggable={false}
        position={markerPosition}
      /> : null}
  </GoogleMap>
);

const GamePanel = ({
  googleApiKey,
  onSelectPoint,
  onSubmitGuess,
  streetViewPoint,
  selectedPoint,
  roundSeconds,
  onTimeout,
}) => (
  <div style={{
    height: "100%",
    display: "flex",
    justifyContent: "space-between",
    alignItems: "center"
  }}>
    <div style={{ height: "100%", margin: "2px", flex: 3 }}>
      <div style={{ position: "relative", height: "100%" }}>
        <PositionedStreetView
          googleMapURL={getMapUrl(googleApiKey)}
          point={streetViewPoint}
        />
      </div>
    </div>
    <div style={{
      height: "100%",
      flex: 1,
      display: "flex",
      flexDirection: "column",
      justifyContent:"space-around",
    }}>
      <RoundTimer style={{ flex: 1 }} seconds={roundSeconds} onTimeout={onTimeout} />
      <div style={{ height: "100%", margin: "5px", flex: 6 }}>
        <SelectionMap
          googleMapURL={getMapUrl(googleApiKey)}
          onClick={({ latLng }) => onSelectPoint({ lat: latLng.lat(), lng: latLng.lng() })}
          markerPosition={selectedPoint}
        />
      </div>
      <button
        style={{ margin: "5px", flex: 1 }}
        onClick={onSubmitGuess}
        disabled={selectedPoint === null}
      >
        Submit Guess
      </button>
    </div>
  </div>
);

export default GamePanel;
