const API_BASE = "https://kirkleon.ddns.net/terrassumptions/api";

export const getStatus = async () => {
    try {
        const res = await fetch(API_BASE);
        if (!res.ok) {
            throw Error(res.statusText);
        }
        return await res.json();
    } catch (err) {
        return {status: err.message, version: null}
    }
}

export const getGoogleApiKey = async () => {
    const res = await fetch(`${API_BASE}/googleApiKey`);
    if (!res.ok) {
        throw Error(res.statusText);
    }
    const { googleApiKey } = await res.json();
    return googleApiKey;
}

export const createGame = async (name, timer) => {
    const res = await fetch(`${API_BASE}/game`, {
        method: "PUT",
        headers: {
            "Authorization": `Name ${name}`,
            "Content-Type": "application/json",
        },
        body: JSON.stringify({ timer }),
    });
    if (!res.ok) {
        throw Error(res.statusText);
    }
    const { gameId } = await res.json();
    return gameId;
}

export const gameInfo = async (gameId) => {
    const res = await fetch(`${API_BASE}/game/${gameId}`);
    if (!res.ok) {
        throw Error(res.statusText);
    }
    return await res.json();
}

export const joinGame = async (gameId, name) => {
    const res = await fetch(`${API_BASE}/game/${gameId}/join`, {
        method: "POST",
        headers: {
            "Authorization": `Name ${name}`
        },
    });
    if (!res.ok) {
        throw Error(res.statusText);
    }
}

export const getGuesses = async (gameId, name) => {
    const res = await fetch(`${API_BASE}/game/${gameId}/guesses`, {
        headers: {
            "Authorization": `Name ${name}`
        },
    });
    if (!res.ok) {
        throw Error(res.statusText);
    }
    return await res.json();
}

export const sendGuess = async (gameId, name, round, point) => {
    const res = await fetch(`${API_BASE}/game/${gameId}/guesses/${round}`, {
        method: "POST",
        headers: {
            "Authorization": `Name ${name}`,
            "Content-Type": "application/json",
        },
        body: JSON.stringify(point),
    });
    if (!res.ok) {
        throw Error(res.statusText);
    }
    return await res.json();
}
